﻿/*
 *  "GEDKeeper", the personal genealogical database editor.
 *  Copyright (C) 2009-2019 by Sergey V. Zhdanovskih.
 *
 *  This file is part of "GEDKeeper".
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System.IO;
using System.Text;
using BSLib;

namespace GDModel.Providers
{
    /// <summary>
    /// Abstract class of generalized provider of files read / write operations.
    /// </summary>
    public abstract class FileProvider
    {
        protected readonly GDMTree fTree;


        protected FileProvider(GDMTree tree)
        {
            fTree = tree;
        }

        public abstract string GetFilesFilter();

        public void LoadFromString(string strText, bool charsetDetection = false)
        {
            using (MemoryStream stream = new MemoryStream(Encoding.UTF8.GetBytes(strText))) {
                LoadFromStreamExt(stream, stream, charsetDetection);
            }
        }

        public void LoadFromFile(string fileName, bool charsetDetection = false)
        {
            using (FileStream fileStream = new FileStream(fileName, FileMode.Open, FileAccess.Read)) {
                LoadFromStreamExt(fileStream, fileStream, charsetDetection);
            }
        }

        public virtual void LoadFromStreamExt(Stream fileStream, Stream inputStream, bool charsetDetection = false)
        {
            using (StreamReader reader = FileHelper.OpenStreamReader(inputStream, GetDefaultEncoding())) {
                fTree.Clear();
                string streamCharset = DetectCharset(inputStream, charsetDetection);
                LoadFromReader(fileStream, reader, streamCharset);
            }
        }

        protected abstract Encoding GetDefaultEncoding();

        protected abstract string DetectCharset(Stream inputStream, bool charsetDetection);

        protected abstract void LoadFromReader(Stream fileStream, StreamReader reader, string streamCharset = null);
    }
}
